==> opencpn_5.10.0+dfsg.orig.tar.xz: opencpn-5.10.0/model/include/model/comm_util.h <==
/***************************************************************************
 *
 * Project:  OpenCPN
 * Purpose:  Misc driver utilities
 * Author:   David Register, Alec Leamas
 *
 ***************************************************************************
 *   Copyright (C) 2022 by David Register, Alec Leamas                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
 **************************************************************************/

#ifndef _COMM_UTIL_H
#define _COMM_UTIL_H

#include "model/comm_navmsg.h"

bool StopAndRemoveCommDriver(std::string ident, NavAddr::Bus = NavAddr::Bus::Undef);

wxString ProcessNMEA4Tags(wxString& msg);

#endif  // _COMM_UTIL_H

==> opencpn_5.10.2+dfsg.orig.tar.xz: opencpn-5.10.2/model/include/model/comm_util.h <==
/***************************************************************************
 *
 * Project:  OpenCPN
 * Purpose:  Misc driver utilities
 * Author:   David Register, Alec Leamas
 *
 ***************************************************************************
 *   Copyright (C) 2022 by David Register, Alec Leamas                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA.         *
 **************************************************************************/

#ifndef _COMM_UTIL_H
#define _COMM_UTIL_H

#include "model/comm_navmsg.h"

bool StopAndRemoveCommDriver(std::string ident,
                             NavAddr::Bus = NavAddr::Bus::Undef);

wxString ProcessNMEA4Tags(wxString& msg);

#endif  // _COMM_UTIL_H
